@@ -497,6 +497,11 @@ class AnalysisView(BaseModel):
     weekly_growth: Optional[float] = None
     monthly_growth: Optional[float] = None
     upside: Optional[float] = None
+    oai_high_price_target: Optional[float] = None
+    oai_low_price_target: Optional[float] = None
+    rsi: Optional[float] = None
+    oai_recommendation: Optional[str] = None
+    oai_moat: Optional[bool] = None
 
 
 def json_loads(value: Any) -> Any:
@@ -527,11 +532,26 @@ class SubjectAnalysis(BaseModel):
     ] = None
     summary: Annotated[Optional[Dict[str, Any]], BeforeValidator(json_loads)] = None
     upside: Optional[float] = None
+    downside: Optional[float] = None
+
+    oai_high_price_target: Optional[float] = None
+    oai_low_price_target: Optional[float] = None
+    oai_news_date: Optional[datetime] = None
+    oai_recent_news: Optional[str] = None
+    oai_recommendation: Optional[str] = None
+    oai_explanation: Optional[str] = None
+    oai_moat: Optional[bool] = None
 
     def compute_upside(self, last_price: float) -> None:
-        if self.high_price_target is not None:
+        if self.oai_high_price_target is not None:
             self.upside = (
-                (float(self.high_price_target) - float(last_price))
+                (float(self.oai_high_price_target) - float(last_price))
+                * 100
+                / float(last_price)
+            )
+        if self.oai_low_price_target is not None:
+            self.downside = (
+                (float(last_price) - float(self.oai_low_price_target))
                 * 100
                 / float(last_price)
             )
@@ -541,12 +561,17 @@ class SubjectAnalysis(BaseModel):
             return None
         return "".join(
             [
-                f"<p>{scrub(t.get('content').replace("\n",""))}</p>"  # type: ignore
+                f"<p>{t.get('content').replace("\n","")}</p>"  # type: ignore
                 for t in self.news_summary
                 if t.get("content")
             ]
         )
 
+    def to_date(self) -> Optional[date]:
+        if self.news_date:
+            return self.news_date.date()
+        return None
+
 
 class Analysis(SubjectAnalysis, AnalysisEarningsDate, AnalysisView, BaseEquity, TechnicalAnalysis, FundamentalAnalysis):  # type: ignore
 
